/******************************************************************************
 * HI 5323 Image Processing
 *
 * histoview.cpp
 ******************************************************************************/

/**
 * class name: HistoView.cpp
 * implement the HistoView class, initialize the class through constructor
 * implement how to draw the histogram based on the graylevel per pixel
*/

#include <qimage.h>
#include <qpainter.h>
#include <qwidget.h>

#include "histoview.h"

/**
 * constructor: HistoView
 * set background for drawing histogram, initialized the array
 */
HistoView::HistoView( const ulong* pHist, QWidget* pParent, const char* pName )
    : QWidget( pParent, pName )
{

  setBackgroundColor( QColor(125, 125, 125) );

  setMinimumSize( 256, 128 );
  setMaximumSize( 256, 1024 );
  
  m_iMax = 0;
  for ( uint i = 0; i < 256; i++ )
      if ( (m_aHist[i] = pHist[i]) > m_iMax ) m_iMax = m_aHist[i];
}

/**
 * paintEvent(QPaintEvent *)
 * draw the histogram image corresponing to the image graph
 */
void HistoView::paintEvent(QPaintEvent *)
{
    int iMaxY = height() - 1;
    uint iH = height();
    QPainter p(this);

    p.setBrush( QColor(0xFF,0xFF,0xFF) );
    for ( int i = 0; i < 256; i++ )
	p.drawLine( i, iMaxY - (uint)((float)m_aHist[i] * iH / m_iMax + 0.5), i, iMaxY );
}
